@@ -131,7 +131,7 @@
 	# assign solver constraints (solnp directly else exterior type penalty
 	# for other solvers)
 	if(fit.control$stationarity == 1 && modelinc[15] == 0){
-		Ifn = rugarch:::.csgarchcon
+		Ifn = .csgarchcon
 		ILB = c(1e-16, 1e-16)
 		IUB = c(1,1)
 		if(solver == "solnp" | solver == "gosolnp" | solver == "hybrid") fit.control$stationarity = 0
@@ -148,7 +148,7 @@
 		if(modelinc[1] > 0) parscale["mu"] = abs(mean(zdata))
 		if(modelinc[7] > 0) parscale["omega"] = var(zdata)
 		arglist$returnType = "llh"
-		solution = .garchsolver(solver, pars = ipars[estidx, 1], fun = rugarch:::.csgarchLLH, 
+		solution = .garchsolver(solver, pars = ipars[estidx, 1], fun = .csgarchLLH, 
 				Ifn, ILB, IUB, gr = NULL, hessian = NULL, parscale = parscale, 
 				control = solver.control, LB = ipars[estidx, 5], 
 				UB = ipars[estidx, 6], ux = NULL, ci = NULL, mu = NULL, 
