@@ -175,7 +175,7 @@
 	# for other solvers)
 	if(fit.control$stationarity == 1 && modelinc[15] == 0){
 		cb = .garchconbounds()
-		Ifn = rugarch:::.sgarchcon
+		Ifn = .sgarchcon
 		ILB = cb$LB
 		IUB = cb$UB
 		if(solver == "solnp" | solver == "gosolnp" | solver == "hybrid") fit.control$stationarity = 0
@@ -192,7 +192,7 @@
 		if(modelinc[1] > 0) parscale["mu"] = abs(mean(as.numeric(zdata)))
 		if(modelinc[7] > 0) parscale["omega"] = var(as.numeric(zdata))
 		arglist$returnType = "llh"
-		solution = .garchsolver(solver, pars = ipars[estidx, 1], fun = rugarch:::.mcsgarchLLH, 
+		solution = .garchsolver(solver, pars = ipars[estidx, 1], fun = .mcsgarchLLH, 
 				Ifn, ILB, IUB, gr = NULL, hessian = NULL, parscale = parscale, 
 				control = solver.control, LB = ipars[estidx, 5], 
 				UB = ipars[estidx, 6], ux = NULL, ci = NULL, mu = NULL, arglist)
@@ -243,7 +243,7 @@
 			arglist$estidx = estidx	
 		}
 		arglist$data = data
-		fit = .makefitmodel(garchmodel = "mcsGARCH", f = rugarch:::.mcsgarchLLH, T = T, m = m, 
+		fit = .makefitmodel(garchmodel = "mcsGARCH", f = .mcsgarchLLH, T = T, m = m, 
 				timer = timer, convergence = convergence, message = sol$message, 
 				hess, arglist = arglist)
 		model$modelinc[7] = modelinc[7]
