@@ -134,9 +134,6 @@ rugarch.test1b = function(cluster=NULL){
 	cat("\nlikelihood method:\n")
 	print(cbind(likelihood(filt[[1]]), likelihood(fit[[1]])))
 	cat("\nresiduals method:\n")
-	# Note that we the package will always return the full length residuals and fitted
-	# object irrespective of the lags (i.e. since this is an ARMA(1,1) i.e. max lag = 1,
-	# the first row is zero and should be discarded.
 	print(cbind(head(residuals(filt[[1]])), head(residuals(fit[[1]]))))
 	cat("\nuncmean method:\n")
 	print(cbind(uncmean(filt[[1]]), uncmean(fit[[1]])))
@@ -226,19 +223,18 @@ rugarch.test1c = function(cluster=NULL){
 	postscript("test1c.eps", width = 12, height = 5)
 	# generate FWD dates:
 	dx = as.POSIXct(tail(rownames(sp500ret),50)) 
-	df = .genxts(tail(dx, 1), length.out = 100+1, period = forc[[1]]@model$modeldata$period)[-1]
-		
+	df = generatefwd(tail(dx, 1), length.out = 100+1, by = forc[[1]]@model$modeldata$period)[-1]		
 	dd = c(dx, df)
 	clrs = rainbow(9, alpha = 1, start = 0.4, end = 0.95)
-	plot(xts(c(tail(sp500ret[,1], 50), nforc[,1]), dd), type = "l", ylim = c(-0.02, 0.02), col = "lightgrey",
+	plot(xts::xts(c(tail(sp500ret[,1], 50), nforc[,1]), dd), type = "l", ylim = c(-0.02, 0.02), col = "lightgrey",
 			ylab = "", xlab = "", main = "100-ahead Unconditional Forecasts", 
 			minor.ticks=FALSE, auto.grid=FALSE)
 	for(i in 1:9){
 		tmp = c(tail(sp500ret[,1], 50), rep(NA, 100))
 		tmp[51:150] = nforc[1:100,i]
-		lines(xts(c(rep(NA, 50), tmp[-(1:50)]),dd), col = clrs[i])
+		lines(xts::xts(c(rep(NA, 50), tmp[-(1:50)]),dd), col = clrs[i])
 	}
-	legend("topleft", legend = dist, col = clrs, fill = clrs, bty = "n")
+	legend("topright", legend = dist, col = clrs, fill = clrs, bty = "n")
 	dev.off()
 	toc = Sys.time()-tic
 	cat("Elapsed:", toc, "\n")
@@ -284,14 +280,14 @@ rugarch.test1d = function(cluster=NULL){
 	par(mfrow = c(1,2))
 	dd = as.POSIXct(tail(rownames(sp500ret), 1250)) 
 	clrs = rainbow(9, alpha = 1, start = 0.4, end = 0.95)
-	plot(xts(tail(sp500ret[,1], 1250), dd), type = "l", ylim = c(-0.02, 0.02), 
+	plot(xts::xts(tail(sp500ret[,1], 1250), dd), type = "l", ylim = c(-0.02, 0.02), 
 			col = "lightgrey", ylab = "", xlab = "", 
 			main = "Rolling 1-ahead Forecasts\nvs Actual", minor.ticks=FALSE, 
 			auto.grid=FALSE)
 	for(i in 1:9){
 		tmp = tail(sp500ret[,1], 1250)
 		tmp[251:1250] = rollforc[1:1000,i]
-		lines(xts(c(rep(NA, 250), tmp[-(1:250)]), dd), col = clrs[i])
+		lines(xts::xts(c(rep(NA, 250), tmp[-(1:250)]), dd), col = clrs[i])
 	}
 	legend("topleft", legend = dist, col = clrs, fill = clrs, bty = "n")
 	
@@ -484,15 +480,20 @@ rugarch.test1g = function(cluster=NULL){
 					shape = 5, sigma = 0.0123))
 	spec2 = arfimaspec( mean.model = list(armaOrder = c(2,1), include.mean = TRUE, arfima = FALSE), 
 			distribution.model = "std", fixed.pars = list(mu = 0.02, ar1 = 0.6, ar2 = 0.01, ma1 = -0.7,
-					shape = 5,sigma = 0.0123))
-	sim1 = arfimapath(spec1, n.sim = 1000, m.sim = 1, rseed = 100)
+					shape = 5, sigma = 0.0123))
+	
+	sim1 = arfimapath(spec1, n.sim = 1000, m.sim = 1, rseed = 100, preresiduals = c(0,0), prereturns = c(0,0),
+			n.start=1)
 	sim2 = arfimapath(spec2, n.sim = 1000, m.sim = 1, rseed = 100)
 	
+	sim1 = arfimapath(spec1, n.sim = 1000, m.sim = 1, rseed = 100, n.start=1)
+	sim2 = arfimapath(spec2, n.sim = 1000, m.sim = 1, rseed = 100, n.start=1)
+	
 	zz <- file("test1g-1.txt", open="wt")
 	sink(zz)
 	cat("\nARFIMA and ARMA simulation tests:\n")
-	print(head(as.data.frame(sim1)), digits = 5)
-	print(head(as.data.frame(sim2)), digits = 5)
+	print(tail(fitted(sim1)), digits = 5)
+	print(tail(fitted(sim2)), digits = 5)
 	sink(type="message")
 	sink()
 	close(zz)
@@ -532,12 +533,13 @@ rugarch.test1g = function(cluster=NULL){
 	sim3 = arima.sim(model = list(ar = c(0.6, 0.21), ma = c(-0.7, 0.3)), n = 1000,
 			n.start = 4, start.innov = c(0,0,0,0), innov = inn*0.0123)
 	
+	# set fracdiff setting to n.start=0 and allow.0.nstart=TRUE
 	sim4 = fracdiff.sim(n=1000, ar = c(0.6, 0.21), ma = c(0.7, -0.3), d = 0,
-			innov = c(0,0,inn*0.0123), n.start = NA, backComp = TRUE, allow.0.nstart = FALSE,
+			innov = c(0,0,inn*0.0123), n.start = 0, backComp = TRUE, allow.0.nstart = TRUE,
 			 mu = 0)
 	
-	tst1 = cbind(head(as.data.frame(sim1)), head(as.data.frame(sim2)), head(as.data.frame(sim3)), head(sim4$series), head(as.data.frame(simx, which = "series")))
-	tst2 = cbind(tail(as.data.frame(sim1)), tail(as.data.frame(sim2)), tail(as.data.frame(sim3)), tail(sim4$series), tail(as.data.frame(simx, which = "series")))
+	tst1 = cbind(head(fitted(sim1)), head(fitted(sim2)), head(sim3), head(sim4$series), head(fitted(simx)))
+	tst2 = cbind(tail(fitted(sim1)), tail(fitted(sim2)), tail(sim3), tail(sim4$series), tail(fitted(simx)))
 	
 	colnames(tst1) = colnames(tst2) = c("ARFIMA(d = 0)", "ARMA", "arima.sim", "fracdiff", "GARCH(0,0)")
 	
@@ -582,8 +584,8 @@ rugarch.test1g = function(cluster=NULL){
 	sim3 = arima.sim(model = list(ar = c(0.6, 0.21), ma = c(-0.7)), n = 1000,
 			n.start = 3, start.innov = c(0,0,0), innov = inn*0.0123)
 	
-	tst1 = cbind(head(as.data.frame(sim1)), head(as.data.frame(sim2)), head(as.data.frame(sim3)), head(as.data.frame(simx, which = "series")) )
-	tst2 = cbind(tail(as.data.frame(sim1)), tail(as.data.frame(sim2)), tail(as.data.frame(sim3)), tail(as.data.frame(simx, which = "series")) )
+	tst1 = cbind(head(fitted(sim1)), head(fitted(sim2)), head(sim3), head(fitted(simx)))
+	tst2 = cbind(tail(fitted(sim1)), tail(fitted(sim2)), tail(sim3), tail(fitted(simx)))
 	
 	colnames(tst1) = colnames(tst2) = c("ARFIMA(d = 0)", "ARMA", "arima.sim", "GARCH(0,0)")
 	
@@ -627,8 +629,9 @@ rugarch.test1g = function(cluster=NULL){
 	sim3 = arima.sim(model = list(ar = c(0.6, 0.21), ma = NULL), n = 1000,
 			n.start = 2, start.innov = c(0,0), innov = inn*0.0123)
 	
-	tst1 = cbind(head(as.data.frame(sim1)), head(as.data.frame(sim2)), head(as.data.frame(sim3)), head(as.data.frame(simx, which = "series")) )
-	tst2 = cbind(tail(as.data.frame(sim1)), tail(as.data.frame(sim2)), tail(as.data.frame(sim3)), tail(as.data.frame(simx, which = "series")) )
+	tst1 = cbind(head(fitted(sim1)), head(fitted(sim2)), head(sim3), head(fitted(simx)))
+	tst2 = cbind(tail(fitted(sim1)), tail(fitted(sim2)), tail(sim3), tail(fitted(simx)))
+	
 	colnames(tst1) = colnames(tst2) = c("ARFIMA(d = 0)", "ARMA", "arima.sim", "GARCH(0,0)")
 	
 	zz <- file("test1g-4.txt", open="wt")
@@ -674,8 +677,8 @@ rugarch.test1g = function(cluster=NULL){
 	sim3 = arima.sim(model = list(ar = NULL, ma = c(0.6, -0.21)), n = 1000,
 			n.start = 2, start.innov = c(0,0), innov = inn*0.0123)
 	
-	tst1 = cbind(head(as.data.frame(sim1)), head(as.data.frame(sim2)), head(as.data.frame(sim3)), head(as.data.frame(simx, which = "series")) )
-	tst2 = cbind(tail(as.data.frame(sim1)), tail(as.data.frame(sim2)), tail(as.data.frame(sim3)), tail(as.data.frame(simx, which = "series")) )
+	tst1 = cbind(head(fitted(sim1)), head(fitted(sim2)), head(sim3), head(fitted(simx)))
+	tst2 = cbind(tail(fitted(sim1)), tail(fitted(sim2)), tail(sim3), tail(fitted(simx)))
 	colnames(tst1) = colnames(tst2) = c("ARFIMA(d = 0)", "ARMA", "arima.sim", "GARCH(0,0)")
 	
 	zz <- file("test1g-5.txt", open="wt")
